#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
from yum.callbacks import DownloadBaseCallback


#
# CONSTANTS
#
FOLLOW_PROGRESS = {
    "operation": "",
    "percent": "",
    "package": "",
    "url": ""
}


#
# CODE
#
class DownloadCallback(DownloadBaseCallback):
    """
    Handles the progress of the download
    """

    def __init__(self, callback):
        """
        Constructor

        Args:
            callback (method): user callback
        """
        # call parent constructor
        DownloadBaseCallback.__init__(self)

        # initialize packages URL dictionary
        self.__packagesUrl = {}

        # set user callback
        self.__userCallback = callback

    def updateProgress(self, name, frac, fread, ftime):
        """
        Updates the progressbar

        Args:
            name (basestring): filename
            frac (float): Progress fraction (0 -> 1)
            fread (basestring): formated string containing BytesRead
            ftime  (basestring): formated string containing remaining or elapsed time
        """
        # space separated name: use only second part
        parts = name.split()

        if len(parts) > 1:
            name = parts[1]

        # name does not have an associated URL: abort
        if name not in self.__packagesUrl:
            return

        # initialize message
        message = {}

        # calculate percentage
        percentage = frac*100

        # create message from template
        message = FOLLOW_PROGRESS.copy()

        # get package URL and name
        message['url'] = self.__packagesUrl[name]
        message['package'] = name

        # percentage is zero: download is starting
        if percentage == 0:
            message['operation'] = 'download-start'

        # percentage is 100: download finish
        elif percentage == 100:
            message['operation'] = 'download-finish'

        # download is in progress
        else:
            message['operation'] = 'download'

        # write percentage
        message['percent'] = percentage

        # report user callback
        self.__userCallback(message)

    def setPackagesUrl(self, dict):
        """
        Setter for packages url

        Args:
            dict (dict): dict with packages url
        """
        self.__packagesUrl = dict.copy()
