#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


"""kernelcmdline.py

Kernel command line arguments parsing and validation.
"""

import re

from controller.pkvmerror import PKVMError
from config import KERNEL_CMDLINE_PATH


class KernelCmdLine:

    def __init__(self):
        self.__argValidators = {'repo': self.isRepoUrlValid}
        self.cmdLine = {}
        self.parse()
        self.validate()

    def parse(self):
        """
        Parse boot command line arguments
        """
        with open(KERNEL_CMDLINE_PATH, 'rt') as f:
            content = f.read()
            for token in content.split():
                (key, _, value) = token.partition('=')
                if key not in self.cmdLine:
                    self.cmdLine[key] = []
                self.cmdLine[key].append(value)

    def get(self, key):
        if key in self.cmdLine:
            return self.cmdLine[key]
        return None

    def hasKey(self, key):
        return self.cmdLine.has_key(key)

    def validate(self):
        """
        Checks if data provided to the kernel command-line is valid.
        """
        try:
            # @TODO: use the cmdLine attribute from this class
            with open(KERNEL_CMDLINE_PATH, 'rt') as f:
                content = f.read()
                for token in content.split():
                    token_splits = token.split('=', 1)
                    if len(token_splits) != 2:
                        continue
                    tag, value = token_splits
                    if tag in self.__argValidators:
                        self.__argValidators[tag](value)
        except IOError:
            raise PKVMError("067")

    def isRepoUrlValid(self, url):
        """
        Check whether a given url for a package repository is valid or
            not.

        Args:
            url (str): url to the package repository.
        """
        # check if repo is http/https/ftp/nfs and return
        if re.match('(https?|ftp|nfs)://', url) is None:
            raise PKVMError("068")
