#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import logging

from blivet import Size

from .config import MIN_DISK_SIZE
from .config import MIN_PASSWORD_LENGTH

#
# CODE
#
class Model(object):
    """
    Abstracts a data model for KoP installer
    """

    def __init__(self):
        """
        Creates a model object
        """
        self.__logger = logging.getLogger(__name__)
        self.__data = {}

    def insert(self, key, value):
        """
        Inserts a new entry in the model

        Args:
            key (str): key of the value to be inserted
            value (?): value to be inserted
        """
        try:
            # key must be string by contract
            assert isinstance(key, str)

            # store the data
            self.__data[key] = value
        except Exception as e:
            self.__logger.critical("%s" % e)

    def get(self, key):
        """
        Retrieved data from model
        The caller is responsible to handle a non existing key

        Args:
            key (str): key of the value to be get

        Returns:
            ?: value
        """
        try:
            # key must be string by contract
            assert isinstance(key, str)

            result = None
            if self.__data.has_key(key):
                result = self.__data[key]

            # return the data
            return result
        except Exception as e:
            self.__logger.critical("%s" % e)

    def hasKey(self, key):
        """
        Check if model has a key defined.

        Args:
            key (str): key of the value to be get

        Returns:
            bool: True if has key, False otherwise
        """
        return self.__data.has_key(key)

    def validatePassword(self, passwd):

        return len(passwd) >= MIN_PASSWORD_LENGTH

    def validateTargetDisks(self, disks):

        # validate that there is at least one target disk
        if disks == []:
            return False, "no_disks"

        # validate minimum total disk size
        disksSize = Size(0)
        for disk in disks:
            disksSize += disk.size
        if disksSize < Size(MIN_DISK_SIZE):
            return False, "insufficient_disk_space"

        return True, ""

# Model
