#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


from modules.network.network import Network
from modules.network.network_interface import NetworkInterface
from socket import gethostbyaddr
from socket import gethostname
from socket import herror

import logging

def reverseDNSLookup():
    """
    Returns a hostname found by performing a reverse DNS lookup for
       each of active NICs' IP address.  Returns the first hostname
       that doesn't point to localhost.

    Returns:
        str: hostname
    """
    hostname = gethostname()
    _logger = logging.getLogger(__name__)
    _logger.debug("Performing reverse DNS lookup to find hostname ...")
    for nicName in Network().getActiveInterfaces():
        nicIPAddress = NetworkInterface(nicName).getIp("127.0.0.1")
        try:
            hostname = gethostbyaddr(nicIPAddress)[0]
        except (IndexError, herror):
            # There's an IP address associated with the NIC but no hostname 
            # was found.
            hostname = "localhost"
        _logger.debug("Reverse DNS lookup - NIC %s IP %s Hostname %s", nicName,
                      nicIPAddress, hostname)
        if hostname != "localhost":
            break
    return hostname

def searchDNSFromFQDN(fqdn):
    """
    Returns the search DNS address for the given FQDN.

    Args:
        fqdn (str): Fully qualified domain name

    Returns:
        str: search DNS address
    """
    return fqdn.split('.', 1)[-1]
