# -*- coding: utf-8 -*-

#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


import locale
import gettext
import os

from model.config import STR_VERSION
from screen_ids import ScreenIds

current_locale = 'en_US'
locale_dir = '/opt/ibm/powerkvm/po/'

# data format: D - day, M - month, Y - year
availableLangs = {
        'pt_BR': {'datetime': 'D M Y'},
        'zh_CN': {'datetime': 'Y M D'},
        'zh_TW': {'datetime': 'Y M D'},
        'fr_FR': {'datetime': 'D M Y'},
        'de_DE': {'datetime': 'D M Y'},
        'it_IT': {'datetime': 'D M Y'},
        'Ja_JP': {'datetime': 'Y M D'},
        'ko_KR': {'datetime': 'Y M D'},
        'ru_RU': {'datetime': 'D M Y'},
        'es_ES': {'datetime': 'D M Y'},
        'en_US': {'datetime': 'M D Y'},
        }


class getTranslation:
    """
    Translation class
    """

    def __init__(self, domain):
        """
        Constructor

        Args:
            domain (basestring): translation domain
        """
        self.domain = domain

        # set default language
        self.current_locale = 'en_US'


    def __call__(self, string):
        """
        Make the translation

        Args:
            string (basestring): text to be translated
        """
        global locale_dir

        return getCustomString(string, self.domain, locale_dir)

    def setLanguage(self, locale):
        """
        Set the current_locale

        Args:
            string (basestring): locale paramete
        """
        global current_locale
        global langConf

        current_locale = locale


_ = getTranslation('powerKVM')


class getCustomString:

    def __init__(self, string, domain, localeDir):
        self.string = string
        self.domain = domain
        self.localeDir = localeDir

    def localize(self):
        global current_locale
        language = gettext.translation(self.domain, self.localeDir, languages=[current_locale])
        language.install()

        return language.ugettext(self.string)

def getLangConf():
    """
    Get the Lang Configuration for the current_locale
    """
    global availableLangs
    return availableLangs[current_locale]

def getAvailableLanguages():
    """
    Get installer available languages

    Returns:
        [(str, str)]l: list of available languages tuples. Each tuple
            has 2 items:
                language code
                language name
    """

    global locale_dir

    language_label = {
        'pt_BR': u'Português(BR)'.encode('utf-8'),
        'zh_TW': u'中国传统'.encode('utf-8'),
        'zh_CN': u'简化中国'.encode('utf-8'),
        'fr_FR': u'Français'.encode('utf-8'),
        'de_DE': u'Deutsch'.encode('utf-8'),
        'it_IT': u'Italiano'.encode('utf-8'),
        'Ja_JP': u'日本語'.encode('utf-8'),
        'ko_KR': u'한국의'.encode('utf-8'),
        'ru_RU': u'Русский'.encode('utf-8'),
        'es_ES': u'Español'.encode('utf-8'),
        }

    license_language_label = {
        'cs': u'Czech'.encode('utf-8'),
        'el': u'Greek'.encode('utf-8'),
        'in': u'Indonesian'.encode('utf-8'),
        'lt': u'Lithuanian'.encode('utf-8'),
        'sl': u'Slovenian'.encode('utf-8'),
        'pl': u'Polish'.encode('utf-8'),
        'tr': u'Turkish'.encode('utf-8'),
        }

    languages = []

    directory_list = os.listdir(locale_dir)
    directory_list.sort()

    languages.append(('English', 'en_US'))
    for i in directory_list:
        if os.path.exists(locale_dir + i + '/LC_MESSAGES/powerKVM.mo'):
            if i != 'en_US' and i != 'ja_JP':
                if i in language_label:
                    languages.append((language_label[i], i))
                else:
                    languages.append((i, i))

    # hack to handle the languages only available for license
    for lang, name in license_language_label.iteritems():
        languages.append((name, lang))

    return languages

def setLanguage(language):
    """
    Set current language

    Args:
        language (str): language language code
    """

    global _

    # use english as default when user selected language
    # only available for the license text
    if len(language) == 2:
        _.setLanguage('en_US')

    else:
        _.setLanguage(language)

def setLanguageKS(lang):
    """
    Set the installer interface to the given language.

    Args:
        lang (str): language to be set

    Returns:
        str: language effectively set
    """
    global _

    if lang in availableLangs:
        current_locale = lang
    else:
        current_locale = 'en_US'

    _.setLanguage(current_locale)

    return current_locale
