#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import logging
import traceback

from controller.pkvmerror import PKVMError
from modules.network.network import Network
from modules.scriptbase import ScriptBase


#
# CODE
#
class NetSetup(ScriptBase):
    """
    Represents a network interface
    """

    def __init__(self, name = None):
        """
        Contructor

        Args:
            name (str): network interface name (default = None)
        """
        self.__logger = logging.getLogger(__name__)
        self.__mountDir = None

    def onPostInstall(self, model):
        """
        Handles the post install event

        Args:
            model (Model): installation data
        """
        try:
            self.__mountDir = model.get('mountDir')

            self.__logger.debug("Copying network config files from image to installed system...")
            Network.copyConfigFile(self.__mountDir)

            self.__logger.debug("Restarting network services in chrooted installed system...")
            Network.restartNetworkService(self.__mountDir)

            if model.get('ntpservers'):
                Network.setNTP(self.__mountDir)

            if model.get('hostname'):
                with open(self.__mountDir + "/etc/hostname", "w") as fd:
                    fd.write(model.get('hostname'))

        except Exception as e:
            raise PKVMError("092")
