#======
# Copyright (c) IBM Corp. 2011, 2015.
# All rights reserved. This program is made available
# under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#=======


#
# IMPORTS
#
import logging
import os
import traceback

from controller.pkvmerror import PKVMError
from modules.scriptbase import ScriptBase


#
# CODE
#
class NTP(ScriptBase):
    """
    Edit the NTP configuration on the system
    """

    def __init__(self):
        """
        Constructor
        """
        self.__logger = logging.getLogger(__name__)
        self.__logger.setLevel(logging.DEBUG)

    def onPostInstall(self, model):
        """
        Handles the post install event

        Args:
            model (Model): installation data
        """
        try:

            serverList = model.get('ntpservers')
            self.__logger.info("Server List: %s" % str(serverList))

            rootDir = model.get('mountDir')

            # get etc directory from installed system
            etcDir = os.path.join(rootDir, 'etc/')

            ntp_file = os.path.join(etcDir, 'ntp.conf')

            # read ntp.conf file content from installed system to adjust it
            fd = open(ntp_file)
            content = fd.readlines()
            fd.close()

            # line just before where the list of server are
            ntp_mark = '# Please consider joining the pool (http://www.pool.ntp.org/join.html).\n'

            for i in content:
                # find the mark line
                if i == ntp_mark:
                    index = content.index(ntp_mark)

                    # clear the lines
                    for line in range(4):
                        content[index + line + 1] = ''

                    x = 1
                    # write the next server lines
                    for server in serverList:
                        content[index + x] = 'server ' + server + ' iburst\n'
                        x = x + 1

                    break

            # put the strings back together
            output = ""
            for i in content:
                output += i

            # update ntp.conf
            fd = open(ntp_file, "w")
            fd.write(output)
            fd.close()

        except Exception as e:
            raise PKVMError("091")
